//
//  EscCommand.h
//  GP_SDK
//
//  Created by ShaoDan on 2018/10/31.
//  Copyright © 2018年 Gainscha. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>



@interface EscCommand : NSObject

//对齐方式
typedef enum :UInt8 {
    Left = 0,
    Middle= 1,
    Right = 2,
}Alignment;


typedef enum {
    Pin_2 = 0,
    Pin_5 = 1,
    
}PinFoot;


//code128
typedef NS_ENUM (NSUInteger,Code128Type) {
    
    CodeA = 1,
    CodeB = 2,
    CodeC = 3,
    
};


//codePage
typedef enum {
    
    PC437 = 0,
    KATAKANA = 1,
    PC850 = 2,
    PC860 = 3,
    PC863 = 4,
    PC865 = 5,
    WEST_EUROPE = 6,
    GREEK = 7,
    HEBREW = 8,
    EAST_EUROPE = 9,
    IRAN = 10,
    WPC1252 = 16,
    PC866 = 17,
    PC852 = 18,
    PC858 = 19,
    IRANII = 20,
    LATVIAN = 21,
    ARABIC = 22,
    PT151 = 23,
    PC747 = 24,
    WPC1257 = 25,
    VIETNAM = 27,
    PC864 = 28,
    PC1001 = 29,
    UYGUR = 30,
    THAI = 255,
    
}CODEPAGE;


typedef enum {
    

    doubleheight_YES = 0,
    doubleheight_NO = 1,
    doublewidth_YES = 2,
    doublewidth_NO = 3,
    underline_YES = 4,
    underline_NO = 5,
    emphasized_YES = 6,
    emphasized_NO = 7,
    
}PrintMode;


typedef enum {
    
    

    FONT_A = 0,
    FONT_B = 1,
    
    
}FONT_A_B;



//打印数据(收集)
@property (nonatomic, strong) NSMutableData *sendRData;



//初始化
+ (EscCommand *)shareInstance;

//连接
- (void)ConnectTheHost:(NSString *)host Port:(UInt16)port Timeout:(NSTimeInterval)timeout;
//断开
- (void)CloseHost;

//发送数据
- (void)SendToThePrinter;


/**
 发送数据带回调

 @param d 要发送的数据
 @param callBack 回调
 */
- (void)SendToThePrinterWithData:(NSData*)d CallBack:(void(^)(NSData *data))callBack;


/**
 初始化打印机
 */
-(void)addInitializePrinter;


/**
 加入跳格符
 */
-(void)addHorTab;


/**
 加入文字
 
 @param content 文本
 */
-(void)addText:(NSString*)content;



/**
 打印并换行
 */
-(void)addPrintAndLineFeed;



/**
 实时产生钱箱开启脉冲
 
 @param foot 引脚
 */
-(void)addGeneratePluseAtRealtime:(PinFoot)foot;


/**
 设置字符右间距
 
 @param n 右间距
 */
-(void)addSetRightSideCharacterSpacing:(int)n;



//设置绝对打印位置
-(void)addSetAbsolutePrintPosition:(NSInteger)location;



/**
 选择/取消下划线模式
 
 @param n 0:取消下划线模式/1:选择下划线模式(1 点宽)/2:选择下划线模式(2 点宽)
 */
-(void)addTurnUnderlineModeOnOrOff:(int)n;



/**
 选择/取消双重打印模式
 
 @param n  当 n 的最低位为0时，取消双重打印模式。/当 n 的最低位为1时，选择双重打印模式。
 */
-(void)addTurnDoubleStrikeOnOrOff:(int)n;


/**
 选择/取消加粗模式
 
 @param n 当 n 的最低位为 0 时，取消加粗模式/当 n 的最低位为 1 时，选择加粗模式。
 */
-(void)addTurnEmphasizedModeOnOrOff:(int)n;



/**
 设置为默认行间距,默认行间距为3.75 mm,约 30 点
 */
-(void)addSelectDefualtLineSpacing;


/**
 设置行间距
 
 @param n 设置行间距为[n × 纵向或横向移动单位]英寸
 */
-(void)addSetLineSpacing:(int)n;


/**
 打印并走纸n个单位
 
 @param n [n × 纵向或横向移动单位]英寸
 */
-(void)addPrintAndFeedPaper:(CGFloat)n;



/**
 打印并走纸n行
 
 @param n 行数
 */
-(void)addPrintAndFeedLines:(int)n;




/**
 选择字体
 
 @param n 0:标准 ASCII 码字体(12 × 24)/1:选择压缩 ASCII 码字体(9 × 17)
 */
-(void)addSelectCharacterFont:(int)n;


/**
 选择国际字符集
 
 
 @param n 0:美国/1:法国/2:德国/3:英国/4:丹麦I/5:瑞典/6:意大利/7:西班牙I/8:日本/9:挪威/10:丹麦II/11:西班牙II/12:拉丁美洲/13:韩国/14:斯洛维尼亚/克罗帝亚/15:中国
 默认是0
 */
-(void)addSelectInternationalCharacterSet:(int)n;


/**
 选择/取消顺时针旋转90度
 
 
 @param n 0:取消顺时针旋转 90 度模式/1:选择顺时针旋转 90 度模式
 */
-(void)addTurn90ClockWiseRotatin:(int)n;



/**
 设置相对横向打印位置
 */
-(void)addSetRelativePrintPositon:(NSInteger)location;


/**
 设置对齐方式
 
 @param type 对齐位置
 */
-(void)addSelectJustification:(Alignment)type;



/**
 产生钱箱控制脉冲
 
 @param foot 指定的引脚
 */
-(void)addGeneratePlus:(PinFoot)foot;


/**
 国际代码页
 
 @param c 默认是0
 */
-(void)addSelectCodePage:(CODEPAGE)c;



/**
 选择/取消倒置打印模式
 
 @param n 当n的最低位为0时，取消倒置打印模式。当n的最低位为1时，选择倒置打印模式。
 */
-(void)addTurnUpsideDownModeOnOrOff:(int)n;


/**
 选择字符大小
 
 @param n (1 ≤ 纵向放大倍数 ≤ 8，1 ≤ 横向放大倍数 ≤ 8)
 */
-(void)addSetCharcterSize:(int)n;


/**
 选择/取消黑白反显打印模式
 
 
 @param n 当n的最低位为0时，取消反显打印。当n的最低位为1时，选择反显打印。
 */
-(void)addTurnReverseModeOnOrOff:(int)n;




//设置左边距
-(void)addSetLeftMargin:(CGFloat)left;


/**
 设置水平和垂直单位距离
 
 @param x 水平单位
 @param y  垂直单位
 */
-(void)addSetHorAndVerMotionUnits:(int)x Y:(int)y;




/**
 切纸后走纸
 
 @param n 走纸距离
 */
-(void)addCutAndFeedPaper:(int)n;


/**
 选择切纸模式
 
 @param m 0全切纸，1是半切
 */
-(void)addCutPaper:(int)m;


//设置打印区域宽度
-(void)addSetPrintingAreaWidth:(CGFloat)width;



/**
 * 方法说明：选择打印模式
 * @param n  FontA(0)/FontB(1) 是否倍宽(是：32/否：0) 是否倍高（是：16/否：0） 是否下划线（是：128/否：0） 是否加粗（是：8/否：0）
    n(0-255)，根据n的值设置字符打印模式 多种模式的话可以叠加（十进制计算）
 */

-(void)addSelectPrintModes:(int)n;


/**
 选择汉字模式,打印机上电后自动选择汉字模式
 */
-(void)addSelectKanjiMode;


/**
 选择/取消汉字下划线模式
 
 @param n
 * 0, 48 取消汉字下划线
 * 1, 49 选择汉字下划线（1 点宽）
 * 2, 50 选择汉字下划线（2点宽）
 */
-(void)addSetKanjiUnderLineMode:(int)n;


/**
 取消汉字模式
 */
-(void)addCancelKanjiMode;



/**
 设置汉字字符左右间距
 
 @param n1 0 ≤ n1 ≤ 255
 @param n2 0 ≤ n2 ≤ 255
 */
-(void)addSetKanjiLeftAndRightSpacing:(int) n1 :(int) n2;



/**
 选择/取消汉字倍高倍宽
 
 
 @param n 当n的最低位为0，取消汉字倍高倍宽模式。当n的最低位为1，选择汉字倍高倍宽模式。
 */
-(void)addSetQuadrupleModeForKanji:(int)n;




/**
 打印光栅位图
 
 @param image 图片
 @param maxwidth 最大宽度
 */
-(void)addRastBitImage:(UIImage *)image Alignment:(Alignment)alignment maxWidth:(int)maxwidth;



/**
 选择HRI字符的打印位置
 
 @param n  0:不打印 1:条码上方 2:条码下方 3:条码上、下方都打印
 */
-(void)addSelectPrintingPositionForHRICharacters:(int)n;


/**
 * 设置条码字符种类，选择HRI使用字体
 * @param n 固定为0 0,48  标准ASCII码字符 (12 × 24)  1,49  压缩ASCII码字符 (9 × 17)
 */
-(void)addSetFontForHRICharacter:(int)n;


/**
 设置条码高度
 
 @param height 高度 条码高度为n点，默认为40
 */
-(void)addSetBarcodeHeight:(int)height;


/**
 设置条码单元宽度
 
 @param width 条码宽度 2 ≤n ≤6
 */
-(void)addSetBarcodeWidth:(int)width;

//条码类型
-(void)addUPCA:(NSString*)content;
-(void)addUPCE:(NSString*)content;
-(void)addEAN13:(NSString*)content;
-(void)addEAN8:(NSString*)content;
-(void)addCODE39:(NSString*)content;
-(void)addITF:(NSString*)content;
-(void)addCODEBAR:(NSString*)content;
-(void)addCODE93:(NSString*)content;
-(void)addCODE128:(Code128Type)type with:(NSString*)content;



//二维码
/**
 设置 QRCode 的单元模块大小
 
 @param n 1≤n≤9,默认是3
 */
-(void)addSelectSizeOfModuleForQRCode:(int)n;


/**
 设置纠错等级
 
 @param n 48≤n≤51,默认是48
 */
-(void)addSelectErrorCorrectionLevelForQRCode:(int)n;


/**
 将QRCode数据存储到打印机中
 
 @param content Qrcode 字符串
 */
-(void)addStoreQRCodeData:(NSString*)content;


/**
 发送打印QRCode命令
 */
-(void)addPrintQRCode;





/**
 查询状态
 */
-(NSData *)addQueryPrinterStatus;

/**
 查询状态并发送

 @param callBack 带回调
 */
-(void)addQueryPrinterStatusCallBack:(void(^)(NSData *data))callBack;



/**
 查询打印是否完成
 */
-(void)PrintCompletedCallBack:(void(^)(NSData *data))callBack;


/**
 指令集合

 @return data
 */
-(NSMutableData*)getData;



//反馈过来的打印机状态合集
@property(nonatomic,strong)NSMutableDictionary *EscValue;




@end
