//
//  GprinterBlueToothSets.h
//  GP_SDK
//
//  Created by ShaoDan on 2018/11/6.
//  Copyright © 2018年 Gainscha. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreBluetooth/CoreBluetooth.h>

// 发送数据时，需要分段的长度,可修改
#define SendLength   90


typedef NS_ENUM(NSInteger, CBManagerStateError) {
    ErrorUnknown = 0,
    ErrorResetting,
    ErrorUnsupported,         //设备不支持
    ErrorUnauthorized,        //未授权
    ErrorPoweredOff,          //蓝牙可用，但是未打开
    ErrorTimeout,             //搜索超时
};

/**
 *  打印回调
 *
 *  @param completion 是否完成
 *  @param error      错误信息
 */
typedef void(^PrintResult)(CBPeripheral *connectPerpheral, BOOL completion, NSString *error);

/**
 *  扫描成功的block
 *
 *  @param perpherals 蓝牙外设列表
 */
typedef void(^SuccessOfScanPerpheral)(NSArray<CBPeripheral *> *perpherals, BOOL isTimeout);

/**
 *  扫描失败的block
 *
 *  @param error 失败的字典
 */
typedef void(^FailureOfScanPerpheral)(CBManagerStateError error);

/**
 *  连接完成的block
 *
 *  @param perpheral 要连接的蓝牙外设
 */
typedef void(^ConnectSuccess)(CBPeripheral *perpheral, NSError *error);


@interface GprinterBlueToothSets : NSObject


/**
 初始化
 
 */
+ (instancetype)sharedInstance;


/**
 扫描外设
 
 @param success 扫描成功的回调
 @param failure 扫描失败的回调
 @param time 停止扫描时间
 */
- (void)startScanPerpheralSuccess:(SuccessOfScanPerpheral)success failure:(FailureOfScanPerpheral)failure withTimeout:(NSTimeInterval)time;


/**
 连接
 
 @param peripheral 蓝牙对象
 */
- (void)connectPeripheral:(CBPeripheral *)peripheral;

/**
 *  连接蓝牙外设，连接成功后会停止扫描蓝牙外设，block方式返回结果
 *
 *  @param peripheral 要连接的蓝牙外设
 *  @param completion 完成后的回调
 */
- (void)connectPeripheral:(CBPeripheral *)peripheral completion:(ConnectSuccess)completion;


/**
 取消连接
 
 @param peripheral 当前连接的蓝牙
 */
- (void)cancelPeripheral:(CBPeripheral *)peripheral;

/**
 发送数据
 
 @param data 数据
 @param result 结果
 */
- (void)sendPrintData:(NSData *)data completion:(PrintResult)result;


/**
 *  查询蓝牙打印机状态
    相较于addQueryPrinterStatusOfESC可以查到其他的状态
    一般是80机子所使用
 *  @param n   1~4
 *
 */
-(void)SearchBlueToothPrinterStatus:(int)n;

//查询蓝牙机型（80）
-(void)SearchBlueToothPrinterModelNum;


/**
 面单——查询指令
 */
-(void)addQueryPrinterStatusOfCPCL;



/**
 票据机——查询指令
 */
-(void)addQueryPrinterStatusOfESC;


/**
 标签机——查询指令
 */
-(void)addQueryPrinterStatusOfTSC;



/**
 发送查询打印是否完成的指令

 针对票据机
 */
-(void)PrintCompletedCallBack:(void(^)(NSData *data))callBack;



//获取打印机状态的信息集合
//80
@property(nonatomic,strong)NSMutableDictionary *valueDict;

//58_面单
@property(nonatomic,strong)NSMutableDictionary *CpclValue;
//58_标签
@property(nonatomic,strong)NSMutableDictionary *TscValue;
//58_票据
@property(nonatomic,strong)NSMutableDictionary *EscValue;

//票据_打印是否完成
@property(nonatomic,copy) void (^ReceiveResult)(NSData *_Nullable data);


@end
