//
//  TscCommand.h
//  GP_SDK
//
//  Created by ShaoDan on 2018/10/31.
//  Copyright © 2018年 Gainscha. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>


@interface TscCommand : NSObject

typedef enum {
    PIN_2 = 0,
    PIN_5 = 1,
    
}FOOT;




typedef enum {
    DENSITY0 = 0,
    DENSITY1 = 1,
    DENSITY2 = 2,
    DENSITY3 = 3,
    DENSITY4 = 4,
    DENSITY5 = 5,
    DENSITY6 = 6,
    DENSITY7 = 7,
    DENSITY8 = 8,
    DENSITY9 = 9,
    DENSITY10 = 10,
    DENSITY11 = 11,
    DENSITY12 = 12,
    DENSITY13 = 13,
    DENSITY14 = 14,
    DENSITY15 = 15,
}DENSITY;


typedef enum {
    FORWARD = 0,
    BACKWARD = 1,
    
}DIRECTION;


typedef enum {
    DISABLE = 0,
    ENABEL = 1,
}READABLE;

typedef enum {
    ROTATION_0 = 0,
    ROTATION_90 = 90,
    ROTATION_180 =180,
    ROTATION_270 = 270,
}ROTATION;

typedef NS_ENUM (NSUInteger,CodePage){
    
    //    8-bit codepage 字符集代表
    United_States = 437,
    Multilingual = 850,
    Slavic = 852,
    Portuguese = 860,
    Canadian_French = 863,
    Nordic = 865,
    //Windows code page
    Central_Europe = 1250,
    Latin_I =  1252,
    Greek = 1253,
    Turkish = 1254,
    
    //    以下代码页仅限于 12×24 dot 英数字体
    //    WestEurope:WestEurope
    //    Greek:Greek
    //    Hebrew:Hebrew
    //    EastEurope:EastEurope
    //    Iran:Iran
    //    IranII:IranII
    //    Latvian:Latvian
    //    Arabic:Arabic
    //    Vietnam:Vietnam
    //    Uygur:Uygur
    //    Thai:Thai
    WestEurope = 1,
    Greek_01 = 2,
    Hebrew = 3,
    EastEurope = 4,
    Iran = 5,
    IranII = 6,
    Latvian = 7,
    Arabic = 8,
    Vietnam = 9,
    Uygur = 10,
    Thai = 11,
    
    
    WPc1257 = 1257,
    WPC1251 = 1251,
    Cyrillic = 866,
    Pc858 = 858,
    Pc747 = 747,
    Pc864 = 864,
    Pc1001 = 1001,
    
};



typedef NS_ENUM (NSUInteger,BARCODETYPE) {
    CODE128=1,
    
    CODE128M=2,
    
    EAN128=3,
    
    ITF25=4,
    
    ITF25C=5,
    
    CODE39=6,
    
    CODE39C=7,
    
    
    CODE93 = 9,
    
    EAN13 = 10,
    
    EAN13_2 = 11,
    
    EAN13_5 = 12,
    
    EAN8 = 13,
    
    EAN8_2 = 14,
    
    EAN8_5 = 15,
    
    CODA= 16,
    
    CODE39S = 17,
    
    UPCA = 18,
    
    UPCA_2 = 19,
    
    UPCA_5 = 20,
    
    UPCE = 21,
    
    UPCE_2 = 22,
    
    UPCE_5 = 23,
    
    
};


typedef NS_ENUM (NSUInteger,FONTTYPE){
    FONT_1 = 1,
    FONT_2 = 2,
    FONT_3 = 3,
    FONT_4 = 4,
    FONT_5 = 5,
    FONT_6 = 6,
    FONT_7 = 7,
    FONT_8 = 8,
    //    SIMPLIFIED_CHINESE("TSS24.BF2"),
    //    TRADITIONAL_CHINESE("TST24.BF2"),
    //    KOREAN("K"),
    SIMPLIFIED_CHINESE = 9,
    TRADITIONAL_CHINESE = 10,
    KOREAN = 11,
    
};


typedef enum {
    MUL_1 = 1,
    MUL_2 = 2,
    MUL_3 = 3,
    MUL_4 = 4,
    MUL_5 = 5,
    MUL_6 = 6,
    MUL_7 = 7,
    MUL_8 = 8,
    MUL_9 = 9,
    MUL_10 = 10,
}FONTMAGNIFICATION;


typedef NS_ENUM (NSUInteger,EEC){
    
    LEVEL_L  = 1,
    LEVEL_M  = 2,
    LEVEL_Q  = 3,
    LEVEL_H  = 4,
};




//打印数据(收集)
@property (nonatomic, strong) NSMutableData *sendTData;


+ (TscCommand *)shareInstance;

//连接
- (void)ConnectTheHost:(NSString *)host Port:(UInt16)port Timeout:(NSTimeInterval)timeout;

//断开
- (void)CloseHost;

//发送数据
- (void)SendToThePrinter;



/**
 发送数据带回调
 
 @param d 要发送的数据
 @param callBack 回调
 */
- (void)SendToThePrinterWithData:(NSData*)d CallBack:(void(^)(NSData *data))callBack;



/**
 设置标签尺寸
 
 @param width 标签宽度 mm
 @param height 标签高度 mm
 */
-(void)addSizeWithWidth:(int)width  withHeight:(int)height;




/**
 设置间隙长度
 
 @param m 两标签纸中间的垂直距离
 @param n 垂直间距偏移
 */
-(void)addGap:(int)m with:(int)n;




/**
 产生钱箱控制脉冲
 
 @param m 钱箱引脚号
 @param t1 t1x2ms
 @param t2 t2×2ms
 */
-(void)addCashdrwer:(FOOT)m withT1:(int)t1 withT2:(int)t2;


/**
 控制每张标签的停止位置
 
 @param offset 停止偏移量 mm
 */
-(void)addOffsetWithOffset:(int)offset;




/**
 设置打印速度
 
 @param speed 打印速度 1.5/2.0/3.0/4.0
 */
-(void)addSpeed:(float)speed;


/**
 设置打印浓度
 
 @param density 打印浓度
 */
-(void)addDensity:(DENSITY)density;


/**
 设置打印方向
 
 @param direction  打印方向
 */
-(void)addDirection:(DIRECTION)direction;



/**
 设置原点坐标，原点坐标位置与 DIRECION 设置有关
 
 @param x 原点横坐标
 @param y 原点纵坐标
 */
-(void)addReference:(int)x with:(int)y;


/**
 清除打印缓冲区数据
 */
-(void)addClS;


/**
 走纸
 
 @param dot 走纸距离,单位:点
 */
-(void)addFeed:(int)dot;


/**
 退纸
 
 @param dot 退纸距离,单位:点
 */
-(void)addBackFeed:(int)dot;


/**
 走一张标签距离
 */
-(void)addFormFeed;


/**
 标签位置进行一次校准
 */
-(void)addHome;



/**
 打印标签
 
 
 @param m 指定打印的份数
 @param n 每张标签需重复打印的张数
 */
-(void)addPrint:(int)m with:(int)n;



/**
 代码页
 
 @param page 参数
 */
-(void)addCodePage:(CodePage)page;


/**
 设置蜂鸣器
 
 @param level  声音阶级
 @param interval 声音长短
 */
-(void)addSound:(int)level with:(int)interval;


/**
 用于设置打印机走纸时，若走过设定长度仍无法检测到间隙，则打印机 报错
 
 @param n 走纸长度,单位:mm
 */
-(void)addLimitFeed:(int)n;


/**
 在打印缓冲区域上绘制黑块
 
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param width 线宽
 @param height 线高
 */

-(void)addBarWithXstart:(int)x withYstart:(int)y withWidth:(int)width withHeight:(int)height;



/**
 打印一维码
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param type 条码类型
 @param height 条码高度
 @param readable 否打印可识别字符
 @param rotation 条码旋转角度
 @param narrow 窄 bar 宽度
 @param wide 宽 bar 宽度
 @param content 条码数据
 */
-(void)add1DBarcodeWithXstart:(int)x withYstart:(int)y withType:(BARCODETYPE)type withHeight:(int)height withREADABLE:(READABLE)readable withROTATION:(ROTATION)rotation narrow:(int)narrow wide:(int)wide withString:(NSString*)content;




/**
 在打印缓冲区域绘制矩形
 
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param xend 终点横坐标
 @param yend 终点纵坐标
 @param lineThickness 方框线宽
 */
-(void)addBoxWithXstart:(int)x  withYstart:(int)y withXend:(int)xend withYend:(int)yend withThickness:(int)lineThickness;



/**
 在打印缓冲区域绘制位图
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param m 位图模式(0:OVERWRITE,1:OR,2:XOR)
 @param image 图片
 @param maxWidth 最大宽度
 */
-(void)addBitmapWithXstart:(int)x  withYstart:(int)y withMode:(int)m withImage:(UIImage*)image maxWidth:(int)maxWidth;



/**
 擦除打印缓冲区中指定区域的数据
 
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param xwidth 横向宽度
 @param yheight 纵向高度
 */
-(void)addEraseWithXstart:(int)x  WithYstart:(int)y WithXwidth:(int)xwidth withYheight:(int)yheight;


/**
 将指定区域的数据黑白反色
 
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param xwidth 横向宽度
 @param yheight 纵向高度
 */
-(void)addReverseWithXstart:(int)x  withYstart:(int)y withXwidth:(int)xwidth withYheight:(int)yheight;



/**
 在打印缓冲区中绘制文字
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param s 字体类型
 @param rotation 旋转角度
 @param mx 横向放大系数 1-10 倍
 @param my 纵向放大系数 1-10 倍
 @param text 文字字符串
 */
-(void)addTextWithXstart:(int)x  withYstart:(int)y withFont:(FONTTYPE)s withRotation:(ROTATION)rotation withMagnificationRateX:(FONTMAGNIFICATION)mx withMagnificationRateY:(FONTMAGNIFICATION)my withContent:(NSString*)text;


/**
 在打印缓冲区中绘制二维码
 
 @param x 起始横坐标
 @param y 起始纵坐标
 @param qrlevel 纠错级别
 @param cellwidth 单元大小
 @param m 手动（输入M）/自动(输入A)编码
 @param rotation 旋转角度
 @param str 文本
 */
-(void)addQRCodeWithXstart:(int)x  withYstart:(int)y  ECClevel:(EEC)qrlevel withCellwidth:(int)cellwidth withMode:(NSString*)m withRotation:(ROTATION)rotation withString:(NSString*)str;

/**
 设置剥离功能是否开启，仅限于部分机型，默认关闭
 
 @param enable 开启输入"ON"/关闭输入"OFF"
 */
-(void)addPeel:(NSString*)enable;




/**
 设置撕离功能是否开启，默认开启
 
 @param enable 启用撕纸位置走到撕纸处输入"ON"/禁用撕纸位置走到撕纸处，命令在起始位置有效输入"OFF"
 */
-(void)addTear:(NSString*)enable;


/**
 
 用于设置切刀状态，关闭打印机电源后，该设置将会被存储在打印机内存中。
 
 @param enable OFF:关闭切刀功能/BATCH: 在PRINT命令结束后切纸 /pieces:0-65535，用于设置每几个标签进行切纸
 */
-(void)addCut:(NSString*)enable;


/**
 设置打印机出现错误时，是否打印上一张内容，默认开启
 
 
 @param enable 开启输入"ON"/关闭输入"OFF"
 */
-(void)addReprint:(NSString*)enable;



/**
 设置是否按走纸键打印最近一张标签
 
 @param enable 开启输入"ON"/关闭输入"OFF"/AUTO:自动开启此功能/num:按FEED键来按多少下
 */
-(void)addPrintKey:(NSString*)enable;



/**
 查询状态
 */
-(NSData *)addQueryPrinterStatus;


/**
 查询状态并发送
 
 
 @param callBack 带回调
 */
-(void)addQueryPrinterStatusCallBack:(void(^)(NSData *data))callBack;


/**
 指令集合
 
 @return data
 */
-(NSMutableData*)getData;


@property(nonatomic,strong)NSMutableDictionary *TscValue;

@end
